pub fn snap_to_soft_tab_line_col(
text: &Rope,
line: usize,
col: usize,
direction: SnapDirection,
tab_width: usize,
) -> usizeExpand description
If the cursor is inside a soft tab at the start of the line, snap it to the nearest, left or right edge. This version takes a line/column and returns a column.